package com.nova.nova_utils;

import android.app.Activity;

import androidx.annotation.NonNull;

import com.ark.commons.ArkTool;
import com.ark.commons.type.agreement.AgreementInterface;
import com.ark.dict.ConfigMapLoader;
import com.leon.channel.helper.ChannelReaderUtil;

import java.util.Map;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * NovaUtilsPlugin
 */
public class NovaUtilsPlugin implements FlutterPlugin,MethodCallHandler, ActivityAware {

    private  Activity activity;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding binding) {
        final MethodChannel channel = new MethodChannel(binding.getBinaryMessenger(), "nova_utils");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {

    }
    @Override
    public void onMethodCall(MethodCall call, final Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("launchMarket")) {
            CommonUtils.toMarket(activity);
        } else if (call.method.equals("checkUpdate")){
            ArkTool.getUpdateManager().checkUpdate(activity);
        }else if (call.method.equals("rateApp")){
            ArkTool.getRateManager().showRateDialog(activity);
        }else if (call.method.equals("popPrivacy")){
            ArkTool.getAgreementManager().showAgreementDialog(activity);
        }else if (call.method.equals("launchUserAgreement")){
            ArkTool.getAgreementManager().showUserAgreement(activity);
        }else if (call.method.equals("launchPrivacyAgreement")){
            ArkTool.getAgreementManager().showPrivacyAgreement(activity);
        }else if (call.method.equals("setDefaultAgreement")){
            String channel = ChannelReaderUtil.getChannel(activity);
            ArkTool.setDefaultConfig(activity,channel);
            result.success(true);
        }else if (call.method.equals("startAndroidApp")){
            ArkTool.getStartManager().startApp(activity, new AgreementInterface.AgreementCallback() {
                @Override
                public void onConfirm(boolean hasConfig) {
                    result.success(true);
                }
            });
        }else if (call.method.equals("getAdditionalConfigParams")){
            String key = call.arguments();
            Map<String, String> other_data = ConfigMapLoader.getInstance().getConfigBean().getOther_data();
            if (other_data!=null){
                if (other_data.containsKey(key)){
                    result.success(other_data.get(key));
                }else {
                    result.success(null);
                }
            }else {
                result.success(null);
            }

        }else {
            result.notImplemented();
        }
    }


    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {
         activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivity() {

    }

}
